@@ -1,22 +1,8 @@
-package Pcore::Whois v0.2.2;
+package Pcore::Whois v0.2.3;
 
-use Pcore qw[-export -class -const];
-
-has max_threads => ( is => 'ro', isa => PositiveInt, default => 50 );
-has timeout     => ( is => 'ro', isa => PositiveInt, default => 30 );
-has proxy => ( is => 'ro', isa => InstanceOf ['Pcore::AE::Handle::ProxyPool'] );
-
-has threads => ( is => 'ro', default => 0, init_arg => undef );
-
-no Pcore;
-
-BEGIN {
-    our %EXPORT_TAGS = (    #
-        WHOIS_STATUS => [qw[$WHOIS_STATUS_OK $WHOIS_STATUS_NO_SERVER $WHOIS_STATUS_NETWORK $WHOIS_STATUS_BANNED]],
-    );
-}
-
-const our $NOT_AVAIL_DOMAIN => 'cwxtwtqcuduvo78hr0dbrfxpuhv8gmtm';
+use Pcore -class, -const, -export => {    #
+    WHOIS_STATUS => [qw[$WHOIS_STATUS_OK $WHOIS_STATUS_NO_SERVER $WHOIS_STATUS_NETWORK $WHOIS_STATUS_BANNED]],
+};
 
 const our $WHOIS_STATUS_OK        => 200;
 const our $WHOIS_STATUS_NO_SERVER => 404;
@@ -27,6 +13,14 @@ use Pcore::Whois::Data;
 use Pcore::Whois::Server;
 use Pcore::Whois::Server::Response;
 
+has max_threads => ( is => 'ro', isa => PositiveInt, default => 50 );
+has timeout     => ( is => 'ro', isa => PositiveInt, default => 30 );
+has proxy => ( is => 'ro', isa => InstanceOf ['Pcore::AE::Handle::ProxyPool'] );
+
+has threads => ( is => 'ro', default => 0, init_arg => undef );
+
+const our $NOT_AVAIL_DOMAIN => 'cwxtwtqcuduvo78hr0dbrfxpuhv8gmtm';
+
 sub whois ( $self, $domain, $cb ) {
     state $cb_cache = {};
 
