@@ -1,6 +1,6 @@
 package Pcore::Whois::Server;
 
-use Pcore qw[-class];
+use Pcore -class;
 use Pcore::Whois qw[:WHOIS_STATUS];
 use Pcore::AE::Handle;
 use Pcore::Whois::Server::Response;
@@ -10,15 +10,13 @@ has req_format => ( is => 'ro', isa => Str, default  => qq[<: QUERY :>$CRLF] );
 has is_verisign => ( is => 'rwp', isa => Maybe [Bool], default => undef );
 has not_found_md5 => ( is => 'rw', isa => Str );
 
-no Pcore;
-
 sub request ( $self, $query, @ ) {
     my $cb = $_[-1];
 
     my %args = (
         timeout => 30,
         proxy   => undef,
-        @_[ 2 .. $#_ - 1 ]
+        splice @_, 2, -1,
     );
 
     my $runtime_proxy;
@@ -148,11 +146,9 @@ sub _get_request_content ( $self, $query ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 85                   │ Subroutines::ProhibitManyArgs - Too many arguments                                                             │
+## │    3 │ 83                   │ Subroutines::ProhibitManyArgs - Too many arguments                                                             │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 113, 121             │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
-## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 18                   │ CodeLayout::RequireTrailingCommas - List declaration without trailing comma                                    │
+## │    3 │ 111, 119             │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
